==> kafka-streams-6.2.0-ccs-sources.jar: org/apache/kafka/streams/kstream/internals/graph/SourceGraphNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.kstream.internals.graph;

import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
import java.util.regex.Pattern;
import org.apache.kafka.common.serialization.Serde;
import org.apache.kafka.streams.kstream.internals.ConsumedInternal;

abstract public class SourceGraphNode<K, V> extends GraphNode {

    private final Set<String> topicNames;
    private final Pattern topicPattern;
    private final ConsumedInternal<K, V> consumedInternal;

    public SourceGraphNode(final String nodeName,
                           final Collection<String> topicNames,
                           final ConsumedInternal<K, V> consumedInternal) {
        super(nodeName);

        this.topicNames = new HashSet<>(topicNames);
        this.topicPattern = null;
        this.consumedInternal = consumedInternal;
    }

    public SourceGraphNode(final String nodeName,
                           final Pattern topicPattern,
                           final ConsumedInternal<K, V> consumedInternal) {

        super(nodeName);

        this.topicNames = null;
        this.topicPattern = topicPattern;
        this.consumedInternal = consumedInternal;
    }

    public Set<String> topicNames() {
        return Collections.unmodifiableSet(topicNames);
    }

    public Pattern topicPattern() {
        return topicPattern;
    }

    public ConsumedInternal<K, V> consumedInternal() {
        return consumedInternal;
    }

    public Serde<K> keySerde() {
        return consumedInternal.keySerde();
    }

    public Serde<V> valueSerde() {
        return consumedInternal.valueSerde();
    }

}

==> kafka-streams-6.2.9-ccs-sources.jar: org/apache/kafka/streams/kstream/internals/graph/SourceGraphNode.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.kstream.internals.graph;

import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import java.util.Optional;
import java.util.Set;
import java.util.regex.Pattern;
import org.apache.kafka.common.serialization.Serde;
import org.apache.kafka.streams.kstream.internals.ConsumedInternal;

abstract public class SourceGraphNode<K, V> extends GraphNode {

    private final Set<String> topicNames;
    private final Pattern topicPattern;
    private final ConsumedInternal<K, V> consumedInternal;

    public SourceGraphNode(final String nodeName,
                           final Collection<String> topicNames,
                           final ConsumedInternal<K, V> consumedInternal) {
        super(nodeName);

        this.topicNames = new HashSet<>(topicNames);
        this.topicPattern = null;
        this.consumedInternal = consumedInternal;
    }

    public SourceGraphNode(final String nodeName,
                           final Pattern topicPattern,
                           final ConsumedInternal<K, V> consumedInternal) {

        super(nodeName);

        this.topicNames = null;
        this.topicPattern = topicPattern;
        this.consumedInternal = consumedInternal;
    }

    public Optional<Set<String>> topicNames() {
        return topicNames == null ? Optional.empty() : Optional.of(Collections.unmodifiableSet(topicNames));
    }

    public Optional<Pattern> topicPattern() {
        return Optional.ofNullable(topicPattern);
    }

    public ConsumedInternal<K, V> consumedInternal() {
        return consumedInternal;
    }

    public Serde<K> keySerde() {
        return consumedInternal.keySerde();
    }

    public Serde<V> valueSerde() {
        return consumedInternal.valueSerde();
    }

}
